@@ -3,8 +3,6 @@ Test that things work correctly when attempting to filter
 the contents of a bag.
 """
 
-import sys
-sys.path.append('.')
 from tiddlyweb.filters import parse_for_filters
 from tiddlyweb import control
 
