@@ -2,8 +2,6 @@
 Test search via the web.
 """
 
-import sys
-sys.path.append('.')
 
 from wsgi_intercept import httplib2_intercept
 import wsgi_intercept
