@@ -5,7 +5,7 @@ HTML based serializers.
 import urllib
 
 from tiddlyweb.serializations import SerializationInterface
-from tiddlyweb.web.util import encode_name
+from tiddlyweb.web.util import encode_name, escape_attribute_value
 from tiddlyweb.wikitext import render_wikitext
 
 
@@ -58,11 +58,11 @@ class Serialization(SerializationInterface):
         server_prefix = self._server_prefix()
         lines = []
         for tiddler in bag.list_tiddlers():
-            base, base_link, wiki_link, title = \
+            base, base_link, representation_link, title = \
                     self._tiddler_list_info(tiddler)
             if bag.revbag:
                 line = self._tiddler_revision_info(base, base_link, tiddler)
-                wiki_link += '/%s/revisions' % encode_name(tiddler.title)
+                representation_link += '/%s/revisions' % encode_name(tiddler.title)
                 title = 'Revisions of Tiddler %s' % tiddler.title
             else:
                 line = self._tiddler_in_bag_info(base, base_link, tiddler)
@@ -70,7 +70,6 @@ class Serialization(SerializationInterface):
 
         if bag.searchbag:
             title = 'Found Tiddlers'
-            wiki_link = None
 
         output = "\n".join(lines)
         self.environ['tiddlyweb.title'] = title
@@ -80,7 +79,7 @@ class Serialization(SerializationInterface):
 <ul id="tiddlers" class="listing">
 %s
 </ul>
-""" % (self._tiddler_list_header(wiki_link), output)
+""" % (self._tiddler_list_header(representation_link), output)
 
     def recipe_as(self, recipe):
         """
@@ -125,8 +124,8 @@ class Serialization(SerializationInterface):
         """
         Transform the provided tiddler into an HTML
         representation of the tiddler packaged in a
-        DIV. If wikklytext is available the wikitext
-        will be rendered into formatted HTML.
+        DIV. Render the content using the render_wikitext
+        subsystem.
         """
         if tiddler.recipe:
             list_link = 'recipes/%s/tiddlers' % encode_name(tiddler.recipe)
@@ -136,7 +135,7 @@ class Serialization(SerializationInterface):
             list_title = 'Tiddlers in Bag %s' % tiddler.bag
         list_html = ('<div class="tiddlerslink"><a href="%s" ' % list_link +
                 'title="tiddler list">%s</a></div>' % list_title)
-        html = render_wikitext(tiddler, list_link, self.environ)
+        html = render_wikitext(tiddler, self.environ)
         self.environ['tiddlyweb.title'] = tiddler.title
         return list_html + self._tiddler_div(tiddler) + html + '</div>'
 
@@ -154,9 +153,12 @@ class Serialization(SerializationInterface):
         """
         return u'<div class="tiddler" title="%s" server.page.revision="%s" ' \
                 'modifier="%s" modified="%s" created="%s" tags="%s" %s>' % \
-                (tiddler.title, tiddler.revision, tiddler.modifier,
-                        tiddler.modified, tiddler.created,
-                        self.tags_as(tiddler.tags),
+                    (escape_attribute_value(tiddler.title),
+                        tiddler.revision,
+                        escape_attribute_value(tiddler.modifier),
+                        tiddler.modified,
+                        tiddler.created,
+                        escape_attribute_value(self.tags_as(tiddler.tags)),
                         self._tiddler_fields(tiddler.fields))
 
     def _tiddler_fields(self, fields):
@@ -165,8 +167,8 @@ class Serialization(SerializationInterface):
         _tiddler_div.
         """
         output = []
-        for key in fields:
-            output.append('%s="%s"' % (key, fields[key]))
+        for key, val in fields.items():
+            output.append('%s="%s"' % (key, escape_attribute_value(val)))
         return ' '.join(output)
 
     def _tiddler_in_bag_info(self, base, base_link, tiddler):
@@ -180,14 +182,20 @@ class Serialization(SerializationInterface):
             encode_name(tiddler.title),
             tiddler.title)
 
-    def _tiddler_list_header(self, wiki_link):
+    def _tiddler_list_header(self, representation_link):
         """
         The string we present at the top of a list of tiddlers.
         """
-        if wiki_link:
+        if representation_link:
+            extension_types = self.environ.get('tiddlyweb.config', {}).get('extension_types', {}).keys()
+            links = []
+            for extension in extension_types:
+                link = '<a href="%s.%s">%s</a>' % (representation_link, extension, extension)
+                links.append(link)
+            link_info = ' '.join(links)
             return """
-<div id="tiddlersheader"><a href="%s">These Tiddlers as a TiddlyWiki</a></div>
-""" % ('%s.wiki' % wiki_link)
+<div id="tiddlersheader">This list of tiddlers as: %s</div>
+""" % (link_info)
         return ''
 
     def _tiddler_list_info(self, tiddler):
@@ -197,16 +205,16 @@ class Serialization(SerializationInterface):
         if tiddler.recipe:
             base = 'recipes'
             base_link = encode_name(tiddler.recipe)
-            wiki_link = '%s/recipes/%s/tiddlers' % (
+            representation_link = '%s/recipes/%s/tiddlers' % (
                     self._server_prefix(), base_link)
             title = 'Tiddlers in Recipe %s' % tiddler.recipe
         else:
             base = 'bags'
             base_link = encode_name(tiddler.bag)
-            wiki_link = '%s/bags/%s/tiddlers' % (self._server_prefix(),
+            representation_link = '%s/bags/%s/tiddlers' % (self._server_prefix(),
                     base_link)
             title = 'Tiddlers in Bag %s' % tiddler.bag
-        return base, base_link, wiki_link, title
+        return base, base_link, representation_link, title
 
     def _tiddler_revision_info(self, base, base_link, tiddler):
         """
