@@ -2,9 +2,6 @@
 Routines related to sending a list of tiddlers out
 to the web, including sending those tiddlers and
 validating cache headers for list of tiddlers.
-
-These are important because this is what sends
-a TiddlyWiki out.
 """
 
 from sha import sha
@@ -32,23 +29,26 @@ def send_tiddlers(environ, start_response, bag):
         raise HTTP404('No tiddlers in container')
 
     serialize_type, mime_type = get_serialize_type(environ)
-    serializer = Serializer(serialize_type, environ)
 
     content_header = ('Content-Type', mime_type)
     cache_header = ('Cache-Control', 'no-cache')
     response = [content_header, cache_header]
 
-    if serialize_type == 'wiki':
-        if download:
-            response.append(('Content-Disposition',
-                'attachment; filename="%s"' % download))
+    if download:
+        response.append(('Content-Disposition',
+            'attachment; filename="%s"' % download))
     if last_modified:
         response.append(last_modified)
     if etag:
         response.append(etag)
 
-    output = serializer.list_tiddlers(bag)
     start_response("200 OK", response)
+
+    serializer = Serializer(serialize_type, environ)
+    try:
+        output = serializer.list_tiddlers(bag)
+    except NoSerializationError, exc:
+        raise HTTP415('Content type not supported: %s, %s' % (mime_type, exc))
     return [output]
 
 
